cpu/x86: Rename paging structure variables for clarity

The following variables have been renamed:

* PDPE_table -> PDPT (Page Directory Pointer Table)
* PDE_tables -> PDT (Page Directory Table)

This change improves the consistency and clarity of the code
as per AMD Architecture Programmer's Manual document.

PML4 -> PDPT -> PDT -> 2MB Physical Page

TEST=Able to build and boot google/rex64.

Change-Id: Ib57d1d54c2c1f4fcce2315b508ed7643251a20c5
Signed-off-by: Subrata Banik <subratabanik@google.com>
Reviewed-on: https://review.coreboot.org/c/coreboot/+/83101
Tested-by: build bot (Jenkins) <no-reply@coreboot.org>
Reviewed-by: Arthur Heymans <arthur@aheymans.xyz>
Reviewed-by: Jérémy Compostella <jeremy.compostella@intel.com>
diff --git a/src/cpu/x86/64bit/pt.S b/src/cpu/x86/64bit/pt.S
index 67e4b1b..4b2f3c8 100644
--- a/src/cpu/x86/64bit/pt.S
+++ b/src/cpu/x86/64bit/pt.S
@@ -20,16 +20,16 @@
 .global PM4LE
 .align 4096
 PM4LE:
-.quad _GEN_DIR(PDPE_table)
+.quad _GEN_DIR(PDPT)
 
 .align 4096
-PDE_tables: /* identity map 2MiB pages */
+PDT: /* identity map 2MiB pages */
 .rept 2048
-.quad _GEN_PAGE(0x200000 * ((. - PDE_tables) >> 3))
+.quad _GEN_PAGE(0x200000 * ((. - PDT) >> 3))
 .endr
 
 .align 4096
-PDPE_table: /* Point to PDE */
+PDPT: /* Point to PDT */
 .rept 4
-.quad _GEN_DIR(PDE_tables + 4096 * ((. - PDPE_table) >> 3))
+.quad _GEN_DIR(PDT + 4096 * ((. - PDPT) >> 3))
 .endr